@@ -15,3 +15,11 @@ class RegionNotConfigured(DogpileCacheException):
 
 class ValidationError(DogpileCacheException):
     """Error validating a value or option."""
+
+
+class PluginNotFound(DogpileCacheException):
+    """The specified plugin could not be found.
+
+    .. versionadded:: 0.6.4
+
+    """
